@@ -5,6 +5,7 @@
 #include <FL/Fl_Image.H>
 #include <FL/Fl_Table.H>
 #include <FL/Fl_Table_Row.H>
+#include <FL/fl_draw.H>
 
 #define TABLE_CLASS(table)                                                                         \
     struct table##_Derived : public table {                                                        \
@@ -101,67 +102,77 @@
         LOCK(self->table_box((Fl_Boxtype)val));                                                    \
     }                                                                                              \
     int table##_table_box(table *self) {                                                           \
-        LOCK(auto ret = self->table_box());;                                                       \
+        LOCK(auto ret = self->table_box());                                                        \
+        ;                                                                                          \
         return ret;                                                                                \
     }                                                                                              \
     void table##_set_rows(table *self, int val) {                                                  \
         LOCK(self->rows(val));                                                                     \
     }                                                                                              \
     int table##_rows(table *self) {                                                                \
-        LOCK(auto ret = self->rows());;                                                            \
+        LOCK(auto ret = self->rows());                                                             \
+        ;                                                                                          \
         return ret;                                                                                \
     }                                                                                              \
     void table##_set_cols(table *self, int val) {                                                  \
         LOCK(self->cols(val));                                                                     \
     }                                                                                              \
     int table##_cols(table *self) {                                                                \
-        LOCK(auto ret = self->cols());;                                                            \
+        LOCK(auto ret = self->cols());                                                             \
+        ;                                                                                          \
         return ret;                                                                                \
     }                                                                                              \
     void table##_visible_cells(table *self, int *r1, int *r2, int *c1, int *c2) {                  \
         LOCK(self->visible_cells(*r1, *r2, *c1, *c2));                                             \
     }                                                                                              \
     int table##_is_interactive_resize(table *self) {                                               \
-        LOCK(auto ret = self->is_interactive_resize());;                                           \
+        LOCK(auto ret = self->is_interactive_resize());                                            \
+        ;                                                                                          \
         return ret;                                                                                \
     }                                                                                              \
     int table##_row_resize(table *self) {                                                          \
-        LOCK(auto ret = self->row_resize());;                                                      \
+        LOCK(auto ret = self->row_resize());                                                       \
+        ;                                                                                          \
         return ret;                                                                                \
     }                                                                                              \
     void table##_set_row_resize(table *self, int flag) {                                           \
         LOCK(self->row_resize(flag));                                                              \
     }                                                                                              \
     int table##_col_resize(table *self) {                                                          \
-        LOCK(auto ret = self->col_resize());;                                                      \
+        LOCK(auto ret = self->col_resize());                                                       \
+        ;                                                                                          \
         return ret;                                                                                \
     }                                                                                              \
     void table##_set_col_resize(table *self, int flag) {                                           \
         LOCK(self->col_resize(flag));                                                              \
     }                                                                                              \
     int table##_col_resize_min(table *self) {                                                      \
-        LOCK(auto ret = self->col_resize_min());;                                                  \
+        LOCK(auto ret = self->col_resize_min());                                                   \
+        ;                                                                                          \
         return ret;                                                                                \
     }                                                                                              \
     void table##_set_col_resize_min(table *self, int val) {                                        \
         LOCK(self->col_resize_min(val));                                                           \
     }                                                                                              \
     int table##_row_resize_min(table *self) {                                                      \
-        LOCK(auto ret = self->row_resize_min());;                                                  \
+        LOCK(auto ret = self->row_resize_min());                                                   \
+        ;                                                                                          \
         return ret;                                                                                \
     }                                                                                              \
     void table##_set_row_resize_min(table *self, int val) {                                        \
         LOCK(self->row_resize_min(val));                                                           \
     }                                                                                              \
     int table##_row_header(table *self) {                                                          \
-        LOCK(auto ret = self->row_header());;                                                      \
+        LOCK(auto ret = self->row_header());                                                       \
+        ;                                                                                          \
         return ret;                                                                                \
     }                                                                                              \
     void table##_set_row_header(table *self, int flag) {                                           \
         LOCK(self->row_header(flag));                                                              \
     }                                                                                              \
     int table##_col_header(table *self) {                                                          \
-        LOCK(auto ret = self->col_header());;                                                      \
+        LOCK(auto ret = self->col_header());                                                       \
+        ;                                                                                          \
         return ret;                                                                                \
     }                                                                                              \
     void table##_set_col_header(table *self, int flag) {                                           \
@@ -171,42 +182,48 @@
         LOCK(self->col_header_height(height));                                                     \
     }                                                                                              \
     int table##_col_header_height(table *self) {                                                   \
-        LOCK(auto ret = self->col_header_height());;                                               \
+        LOCK(auto ret = self->col_header_height());                                                \
+        ;                                                                                          \
         return ret;                                                                                \
     }                                                                                              \
     void table##_set_row_header_width(table *self, int width) {                                    \
         LOCK(self->row_header_width(width));                                                       \
     }                                                                                              \
     int table##_row_header_width(table *self) {                                                    \
-        LOCK(auto ret = self->row_header_width());;                                                \
+        LOCK(auto ret = self->row_header_width());                                                 \
+        ;                                                                                          \
         return ret;                                                                                \
     }                                                                                              \
     void table##_set_row_header_color(table *self, unsigned int val) {                             \
         LOCK(self->row_header_color(val));                                                         \
     }                                                                                              \
     unsigned int table##_row_header_color(table *self) {                                           \
-        LOCK(auto ret = self->row_header_color());;                                                \
+        LOCK(auto ret = self->row_header_color());                                                 \
+        ;                                                                                          \
         return ret;                                                                                \
     }                                                                                              \
     void table##_set_col_header_color(table *self, unsigned int val) {                             \
         LOCK(self->col_header_color(val));                                                         \
     }                                                                                              \
     unsigned int table##_col_header_color(table *self) {                                           \
-        LOCK(auto ret = self->col_header_color());;                                                \
+        LOCK(auto ret = self->col_header_color());                                                 \
+        ;                                                                                          \
         return ret;                                                                                \
     }                                                                                              \
     void table##_set_row_height(table *self, int row, int height) {                                \
         LOCK(self->row_height(row, height));                                                       \
     }                                                                                              \
     int table##_row_height(table *self, int row) {                                                 \
-        LOCK(auto ret = self->row_height(row));;                                                   \
+        LOCK(auto ret = self->row_height(row));                                                    \
+        ;                                                                                          \
         return ret;                                                                                \
     }                                                                                              \
     void table##_set_col_width(table *self, int col, int width) {                                  \
         LOCK(self->col_width(col, width));                                                         \
     }                                                                                              \
     int table##_col_width(table *self, int col) {                                                  \
-        LOCK(auto ret = self->col_width(col));;                                                    \
+        LOCK(auto ret = self->col_width(col));                                                     \
+        ;                                                                                          \
         return ret;                                                                                \
     }                                                                                              \
     void table##_set_row_height_all(table *self, int height) {                                     \
@@ -222,22 +239,26 @@
         LOCK(self->col_position(col));                                                             \
     }                                                                                              \
     int table##_row_position(table *self) {                                                        \
-        LOCK(auto ret = self->row_position());;                                                    \
+        LOCK(auto ret = self->row_position());                                                     \
+        ;                                                                                          \
         return ret;                                                                                \
     }                                                                                              \
     int table##_col_position(table *self) {                                                        \
-        LOCK(auto ret = self->col_position());;                                                    \
+        LOCK(auto ret = self->col_position());                                                     \
+        ;                                                                                          \
         return ret;                                                                                \
     }                                                                                              \
     void table##_set_top_row(table *self, int row) {                                               \
         LOCK(self->top_row(row));                                                                  \
     }                                                                                              \
     int table##_top_row(table *self) {                                                             \
-        LOCK(auto ret = self->top_row());;                                                         \
+        LOCK(auto ret = self->top_row());                                                          \
+        ;                                                                                          \
         return ret;                                                                                \
     }                                                                                              \
     int table##_is_selected(table *self, int r, int c) {                                           \
-        LOCK(auto ret = self->is_selected(r, c));;                                                 \
+        LOCK(auto ret = self->is_selected(r, c));                                                  \
+        ;                                                                                          \
         return ret;                                                                                \
     }                                                                                              \
     void table##_get_selection(table *self, int *row_top, int *col_left, int *row_bot,             \
@@ -249,15 +270,18 @@
         LOCK(self->set_selection(row_top, col_left, row_bot, col_right));                          \
     }                                                                                              \
     int table##_move_cursor_with_shiftselect(table *self, int R, int C, int shiftselect) {         \
-        LOCK(auto ret = self->move_cursor(R, C, shiftselect));;                                    \
+        LOCK(auto ret = self->move_cursor(R, C, shiftselect));                                     \
+        ;                                                                                          \
         return ret;                                                                                \
     }                                                                                              \
     int table##_move_cursor(table *self, int R, int C) {                                           \
-        LOCK(auto ret = self->move_cursor(R, C));;                                                 \
+        LOCK(auto ret = self->move_cursor(R, C));                                                  \
+        ;                                                                                          \
         return ret;                                                                                \
     }                                                                                              \
     int table##_scrollbar_size(const table *self) {                                                \
-        LOCK(auto ret = self->scrollbar_size());;                                                  \
+        LOCK(auto ret = self->scrollbar_size());                                                   \
+        ;                                                                                          \
         return ret;                                                                                \
     }                                                                                              \
     void table##_set_scrollbar_size(table *self, int newSize) {                                    \
@@ -267,7 +291,8 @@
         LOCK(self->tab_cell_nav(val));                                                             \
     }                                                                                              \
     int table##_tab_cell_nav(const table *self) {                                                  \
-        LOCK(auto ret = self->tab_cell_nav());;                                                    \
+        LOCK(auto ret = self->tab_cell_nav());                                                     \
+        ;                                                                                          \
         return ret;                                                                                \
     }                                                                                              \
     void table##_draw_cell(table *self,                                                            \
@@ -284,15 +309,18 @@
         LOCK(((table##_Derived *)self)->draw_cell_data_ = data)                                    \
     }                                                                                              \
     int table##_callback_col(table *self) {                                                        \
-        LOCK(auto ret = self->callback_col());;                                                    \
+        LOCK(auto ret = self->callback_col());                                                     \
+        ;                                                                                          \
         return ret;                                                                                \
     }                                                                                              \
     int table##_callback_row(table *self) {                                                        \
-        LOCK(auto ret = self->callback_row());;                                                    \
+        LOCK(auto ret = self->callback_row());                                                     \
+        ;                                                                                          \
         return ret;                                                                                \
     }                                                                                              \
     int table##_callback_context(table *self) {                                                    \
-        LOCK(auto ret = self->callback_context());;                                                \
+        LOCK(auto ret = self->callback_context());                                                 \
+        ;                                                                                          \
         return ret;                                                                                \
     }                                                                                              \
     void *table##_scrollbar(const table *self) {                                                   \
